package com.ynet.life.exception;

import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeConstants;
import java.io.ByteArrayOutputStream;
import java.io.PrintStream;
import java.sql.SQLException;

/* loaded from: com_ynet_life_exception.jar:com/ynet/life/exception/TranFailException.class */
public class TranFailException extends GENEException {
    private static final long serialVersionUID = 6857754983999980461L;
    private static final String SQLSTATE_DUPLICATE_INDEX_ORACLE = "23000";
    private static final String SQLSTATE_DUPLICATE_INDEX_DB2 = "23505";
    private static final String ERROR_CODE_DUPLICATE_INDEX = "EBLN5003";
    private boolean printTraceMessage;

    public TranFailException(String errorCode) {
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
    }

    public TranFailException(String errorCode, boolean printMessage) {
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        setPrintTraceMessage(printMessage);
    }

    public TranFailException(String errorCode, String message) {
        super(message);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        super.setShowMessage(message);
    }

    public TranFailException(String errorCode, String message, boolean printMessage) {
        super(message);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        super.setShowMessage(message);
        setPrintTraceMessage(printMessage);
    }

    public TranFailException(String errorCode, Throwable cause) {
        super(cause);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
    }

    public TranFailException(String errorCode, Throwable cause, boolean printMessage) {
        super(cause);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        setPrintTraceMessage(printMessage);
    }

    public TranFailException(String errorCode, String message, Throwable cause) {
        super(message, cause);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        super.setShowMessage(message);
    }

    public TranFailException(String errorCode, String message, Throwable cause, boolean printMessage) {
        super(message, cause);
        this.printTraceMessage = true;
        super.setErrorCode(errorCode);
        super.setShowMessage(message);
        setPrintTraceMessage(printMessage);
    }

    public TranFailException(Throwable cause) {
        super(cause);
        this.printTraceMessage = true;
    }

    public TranFailException(Throwable cause, boolean printMessage) {
        super(cause);
        this.printTraceMessage = true;
        setPrintTraceMessage(printMessage);
    }

    public TranFailException(SQLException ex) {
        super("EBLN0000", (String) null, ex);
        this.printTraceMessage = true;
        String sqlState = ex.getSQLState();
        switch (LifeConstants.DB_TYPE) {
            case 1:
                if (SQLSTATE_DUPLICATE_INDEX_ORACLE.equals(sqlState)) {
                    super.setErrorCode(ERROR_CODE_DUPLICATE_INDEX);
                    return;
                }
                return;
            case 2:
                if (SQLSTATE_DUPLICATE_INDEX_DB2.equals(sqlState)) {
                    super.setErrorCode(ERROR_CODE_DUPLICATE_INDEX);
                    return;
                }
                return;
            default:
                return;
        }
    }

    public String getErrorStack() {
        ByteArrayOutputStream bo = new ByteArrayOutputStream();
        PrintStream ps = new PrintStream(bo);
        printStackTrace(ps);
        return new String(bo.toByteArray());
    }

    public void setPrintTraceMessage(boolean printTraceMessage) {
        this.printTraceMessage = printTraceMessage;
    }

    public boolean isPrintTraceMessage() {
        return this.printTraceMessage;
    }
}
